changeset 5783:f5794b0165c2

Fix spellings in comment.
author Paul Eggert <eggert@cs.ucla.edu>
date Sat, 02 Apr 2005 03:54:44 +0000
parents ec79f98d03e9
children 2a85a3de74c0
files lib/strtol.c
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lib/strtol.c
+++ b/lib/strtol.c
@@ -127,9 +127,9 @@
 /* The extra casts in the following macros work around compiler bugs,
    e.g., in Cray C 5.0.3.0.  */
 
-/* True if negative values of the signed integer type T use twos
-   complement, ones complement, or signed magnitude representation,
-   respectively.  Much GNU code assumes twos complement, but some
+/* True if negative values of the signed integer type T use two's
+   complement, ones' complement, or signed magnitude representation,
+   respectively.  Much GNU code assumes two's complement, but some
    people like to be portable to all possible C hosts.  */
 # define TYPE_TWOS_COMPLEMENT(t) ((t) ~ (t) 0 == (t) -1)
 # define TYPE_ONES_COMPLEMENT(t) ((t) ~ (t) 0 == 0)